==> doxygen_1.6.1.orig.tar.gz: doxygen-1.6.1/src/search_css.h <==
"/*---------------- Search Box */\n"
"\n"
"#MSearchBox {\n"
"    padding: 0px;\n"
"    margin: 0px;\n"
"    border: none;\n"
"    border: 1px solid #84B0C7;\n"
"    white-space: nowrap;\n"
"    -moz-border-radius: 8px;\n"
"    -webkit-border-top-left-radius: 8px;\n"
"    -webkit-border-top-right-radius: 8px;\n"
"    -webkit-border-bottom-left-radius: 8px;\n"
"    -webkit-border-bottom-right-radius: 8px;\n"
"}\n"
"#MSearchField {\n"
"    font: 9pt Arial, Verdana, sans-serif;\n"
"    color: #999999;\n"
"    background-color: #FFFFFF;\n"
"    font-style: normal;\n"
"    cursor: text;\n"
"    padding: 1px 1px;\n"
"    margin: 0px 6px 0px 0px;\n"
"    border: none;\n"
"    outline: none;\n"
"    vertical-align: middle;\n"
"}\n"
".MSearchBoxActive #MSearchField {\n"
"    color: #000000;\n"
"}\n"
"#MSearchSelect {\n"
"    float : none;\n"
"    display : inline;\n"
"    background : none;\n"
"    font: 9pt Verdana, sans-serif;\n"
"    border: none;\n"
"    margin: 0px 0px 0px 6px;\n"
"    vertical-align: middle;\n"
"    padding: 0px 0px;\n"
"}\n"
"\n"
"#MSearchClose {\n"
"    float : none;\n"
"    display : none;\n"
"    background : none;\n"
"    border: none;\n"
"    margin: 0px 4px 0px 0px;\n"
"    padding: 0px 0px;\n"
"    outline: none;\n"
"}\n"
"\n"
"#MSearchCloseImg {\n"
"    vertical-align: middle;\n"
"}\n"
"\n"
".MSearchBoxLeft {\n"
"    display: block;\n"
"    text-align: left;\n"
"    float: left;\n"
"    margin-left: 6px;\n"
"}\n"
".MSearchBoxRight {\n"
"    display: block;\n"
"    float: right;\n"
"    text-align: right;\n"
"    margin-right: 6px;\n"
"}\n"
".MSearchBoxSpacer {\n"
"    font-size: 0px;\n"
"    clear: both;\n"
"}\n"
".MSearchBoxRow {\n"
"    font-size: 0px;\n"
"    clear: both;\n"
"}\n"
"\n"
"/*---------------- Search filter selection */\n"
"\n"
"#MSearchSelectWindow {\n"
"    display: none;\n"
"    position: absolute;\n"
"    left: 0; top: 0;\n"
"    border: 1px solid #A0A0A0;\n"
"    background-color: #FAFAFA;\n"
"    z-index: 1;\n"
"    padding-top: 4px;\n"
"    padding-bottom: 4px;\n"
"    -moz-border-radius: 4px;\n"
"    -webkit-border-top-left-radius: 4px;\n"
"    -webkit-border-top-right-radius: 4px;\n"
"    -webkit-border-bottom-left-radius: 4px;\n"
"    -webkit-border-bottom-right-radius: 4px;\n"
"    -webkit-box-shadow: 5px 5px 5px rgba(0, 0, 0, 0.15);\n"
"    }\n"
".SelectItem {\n"
"    font: 8pt Arial, Verdana, sans-serif;\n"
"    padding-left:  2px;\n"
"    padding-right: 12px;\n"
"    border: 0px;\n"
"}\n"
"span.SelectionMark {\n"
"    margin-right: 4px;\n"
"    font-family: monospace;\n"
"    outline-style: none;\n"
"    text-decoration: none;\n"
"}\n"
"a.SelectItem {\n"
"    display: block;\n"
"    outline-style: none;\n"
"    color: #000000; \n"
"    text-decoration: none;\n"
"    padding-left:   6px;\n"
"    padding-right: 12px;\n"
"}\n"
"a.SelectItem:focus,\n"
"a.SelectItem:active {\n"
"    color: #000000; \n"
"    outline-style: none;\n"
"    text-decoration: none;\n"
"}\n"
"a.SelectItem:hover {\n"
"    color: #FFFFFF;\n"
"    background-color: #2A50E4;\n"
"    outline-style: none;\n"
"    text-decoration: none;\n"
"    cursor: pointer;\n"
"    display: block;\n"
"}\n"
"\n"
"/*---------------- Search results window */\n"
"\n"
"iframe#MSearchResults {\n"
"    width: 60ex;\n"
"    height: 15em;\n"
"    }\n"
"#MSearchResultsWindow {\n"
"    display: none;\n"
"    position: absolute;\n"
"    left: 0; top: 0;\n"
"    border: 1px solid #000000;\n"
"    background-color: #EEF3F5;\n"
"    }\n"
"\n"
"/* ----------------------------------- */\n"
"\n"
"\n"
"#SRIndex {\n"
"    clear:both; \n"
"    padding-bottom: 15px;\n"
"}\n"
"\n"
".SREntry {\n"
"    font-size: 10pt;\n"
"    padding-left: 1ex;\n"
"}\n"
".SRPage .SREntry {\n"
"    font-size: 8pt;\n"
"    padding: 1px 5px;\n"
"}\n"
"body.SRPage {\n"
"    margin: 5px 2px;\n"
"}\n"
"\n"
".SRChildren {\n"
"    padding-left: 3ex; padding-bottom: .5em \n"
"}\n"
".SRPage .SRChildren {\n"
"    display: none;\n"
"}\n"
".SRSymbol {\n"
"    font-weight: bold; color: #153788;\n"
"    font-family: Arial, Verdana, sans-serif;\n"
"    text-decoration: none;\n"
"    outline: none;\n"
"}\n"
"\n"
"a.SRScope {\n"
"    display: block;\n"
"    color: #153788; \n"
"    font-family: Arial, Verdana, sans-serif;\n"
"    text-decoration: none;\n"
"    outline: none;\n"
"}\n"
"\n"
"a.SRSymbol:focus, a.SRSymbol:active,\n"
"a.SRScope:focus, a.SRScope:active {\n"
"    text-decoration: underline;\n"
"}\n"
"\n"
".SRPage .SRStatus {\n"
"    padding: 2px 5px;\n"
"    font-size: 8pt;\n"
"    font-style: italic;\n"
"}\n"
"\n"
".SRResult {\n"
"    display: none;\n"
"}\n"
"\n"

==> doxygen_1.8.3.1.orig.tar.gz: doxygen-1.8.3.1/src/search_css.h <==
"/*---------------- Search Box */\n"
"\n"
"#FSearchBox {\n"
"    float: left;\n"
"}\n"
"\n"
"#MSearchBox {\n"
"    white-space : nowrap;\n"
"    position: absolute;\n"
"    float: none;\n"
"    display: inline;\n"
"    margin-top: 8px;\n"
"    right: 0px;\n"
"    width: 170px;\n"
"    z-index: 102;\n"
"    background-color: white;\n"
"}\n"
"\n"
"#MSearchBox .left\n"
"{\n"
"    display:block;\n"
"    position:absolute;\n"
"    left:10px;\n"
"    width:20px;\n"
"    height:19px;\n"
"    background:url('search_l.png') no-repeat;\n"
"    background-position:right;\n"
"}\n"
"\n"
"#MSearchSelect {\n"
"    display:block;\n"
"    position:absolute;\n"
"    width:20px;\n"
"    height:19px;\n"
"}\n"
"\n"
".left #MSearchSelect {\n"
"    left:4px;\n"
"}\n"
"\n"
".right #MSearchSelect {\n"
"    right:5px;\n"
"}\n"
"\n"
"#MSearchField {\n"
"    display:block;\n"
"    position:absolute;\n"
"    height:19px;\n"
"    background:url('search_m.png') repeat-x;\n"
"    border:none;\n"
"    width:116px;\n"
"    margin-left:20px;\n"
"    padding-left:4px;\n"
"    color: #909090;\n"
"    outline: none;\n"
"    font: 9pt Arial, Verdana, sans-serif;\n"
"}\n"
"\n"
"#FSearchBox #MSearchField {\n"
"    margin-left:15px;\n"
"}\n"
"\n"
"#MSearchBox .right {\n"
"    display:block;\n"
"    position:absolute;\n"
"    right:10px;\n"
"    top:0px;\n"
"    width:20px;\n"
"    height:19px;\n"
"    background:url('search_r.png') no-repeat;\n"
"    background-position:left;\n"
"}\n"
"\n"
"#MSearchClose {\n"
"    display: none;\n"
"    position: absolute;\n"
"    top: 4px;\n"
"    background : none;\n"
"    border: none;\n"
"    margin: 0px 4px 0px 0px;\n"
"    padding: 0px 0px;\n"
"    outline: none;\n"
"}\n"
"\n"
".left #MSearchClose {\n"
"    left: 6px;\n"
"}\n"
"\n"
".right #MSearchClose {\n"
"    right: 2px;\n"
"}\n"
"\n"
".MSearchBoxActive #MSearchField {\n"
"    color: #000000;\n"
"}\n"
"\n"
"/*---------------- Search filter selection */\n"
"\n"
"#MSearchSelectWindow {\n"
"    display: none;\n"
"    position: absolute;\n"
"    left: 0; top: 0;\n"
"    border: 1px solid ##A0;\n"
"    background-color: ##FA;\n"
"    z-index: 1;\n"
"    padding-top: 4px;\n"
"    padding-bottom: 4px;\n"
"    -moz-border-radius: 4px;\n"
"    -webkit-border-top-left-radius: 4px;\n"
"    -webkit-border-top-right-radius: 4px;\n"
"    -webkit-border-bottom-left-radius: 4px;\n"
"    -webkit-border-bottom-right-radius: 4px;\n"
"    -webkit-box-shadow: 5px 5px 5px rgba(0, 0, 0, 0.15);\n"
"}\n"
"\n"
".SelectItem {\n"
"    font: 8pt Arial, Verdana, sans-serif;\n"
"    padding-left:  2px;\n"
"    padding-right: 12px;\n"
"    border: 0px;\n"
"}\n"
"\n"
"span.SelectionMark {\n"
"    margin-right: 4px;\n"
"    font-family: monospace;\n"
"    outline-style: none;\n"
"    text-decoration: none;\n"
"}\n"
"\n"
"a.SelectItem {\n"
"    display: block;\n"
"    outline-style: none;\n"
"    color: #000000; \n"
"    text-decoration: none;\n"
"    padding-left:   6px;\n"
"    padding-right: 12px;\n"
"}\n"
"\n"
"a.SelectItem:focus,\n"
"a.SelectItem:active {\n"
"    color: #000000; \n"
"    outline-style: none;\n"
"    text-decoration: none;\n"
"}\n"
"\n"
"a.SelectItem:hover {\n"
"    color: #FFFFFF;\n"
"    background-color: ##50;\n"
"    outline-style: none;\n"
"    text-decoration: none;\n"
"    cursor: pointer;\n"
"    display: block;\n"
"}\n"
"\n"
"/*---------------- Search results window */\n"
"\n"
"iframe#MSearchResults {\n"
"    width: 60ex;\n"
"    height: 15em;\n"
"}\n"
"\n"
"#MSearchResultsWindow {\n"
"    display: none;\n"
"    position: absolute;\n"
"    left: 0; top: 0;\n"
"    border: 1px solid #000;\n"
"    background-color: ##F0;\n"
"}\n"
"\n"
"/* ----------------------------------- */\n"
"\n"
"\n"
"#SRIndex {\n"
"    clear:both; \n"
"    padding-bottom: 15px;\n"
"}\n"
"\n"
".SREntry {\n"
"    font-size: 10pt;\n"
"    padding-left: 1ex;\n"
"}\n"
"\n"
".SRPage .SREntry {\n"
"    font-size: 8pt;\n"
"    padding: 1px 5px;\n"
"}\n"
"\n"
"body.SRPage {\n"
"    margin: 5px 2px;\n"
"}\n"
"\n"
".SRChildren {\n"
"    padding-left: 3ex; padding-bottom: .5em \n"
"}\n"
"\n"
".SRPage .SRChildren {\n"
"    display: none;\n"
"}\n"
"\n"
".SRSymbol {\n"
"    font-weight: bold; \n"
"    color: ##58;\n"
"    font-family: Arial, Verdana, sans-serif;\n"
"    text-decoration: none;\n"
"    outline: none;\n"
"}\n"
"\n"
"a.SRScope {\n"
"    display: block;\n"
"    color: ##58; \n"
"    font-family: Arial, Verdana, sans-serif;\n"
"    text-decoration: none;\n"
"    outline: none;\n"
"}\n"
"\n"
"a.SRSymbol:focus, a.SRSymbol:active,\n"
"a.SRScope:focus, a.SRScope:active {\n"
"    text-decoration: underline;\n"
"}\n"
"\n"
"span.SRScope {\n"
"    padding-left: 4px;\n"
"}\n"
"\n"
".SRPage .SRStatus {\n"
"    padding: 2px 5px;\n"
"    font-size: 8pt;\n"
"    font-style: italic;\n"
"}\n"
"\n"
".SRResult {\n"
"    display: none;\n"
"}\n"
"\n"
"DIV.searchresults {\n"
"    margin-left: 10px;\n"
"    margin-right: 10px;\n"
"}\n"
"\n"
"/*---------------- External search page results */\n"
"\n"
".searchresult {\n"
"    background-color: ##F2;\n"
"}\n"
"\n"
".pages b {\n"
"   color: white;\n"
"   padding: 5px 5px 3px 5px;\n"
"   background-image: url(\"../tab_a.png\");\n"
"   background-repeat: repeat-x;\n"
"   text-shadow: 0 1px 1px #000000;\n"
"}\n"
"\n"
".pages {\n"
"    line-height: 17px;\n"
"    margin-left: 4px;\n"
"    text-decoration: none;\n"
"}\n"
"\n"
".hl {\n"
"    font-weight: bold;\n"
"}\n"
"\n"
"#searchresults {\n"
"    margin-bottom: 20px;\n"
"}\n"
"\n"
".searchpages {\n"
"    margin-top: 10px;\n"
"}\n"
"\n"
